@@ -25,7 +25,7 @@ typedef int (*dec_decode_cb)(Kit_Decoder *dec, AVPacket *in_packet);
 typedef void (*dec_close_cb)(Kit_Decoder *dec);
 typedef void (*dec_free_packet_cb)(void *packet);
 
-KIT_LOCAL struct Kit_Decoder {
+struct Kit_Decoder {
     int stream_index;            ///< Source stream index for the current stream
     double clock_sync;           ///< Sync source for current stream
     double clock_pos;            ///< Current pts for the stream
