@@ -8,9 +8,7 @@
 #include "kitchensink/internal/kitlibstate.h"
 #include "kitchensink/internal/kitdecoder.h"
 #include "kitchensink/internal/utils/kithelpers.h"
-#include "kitchensink/internal/utils/kitbuffer.h"
 #include "kitchensink/internal/video/kitvideo.h"
-#include "kitchensink/internal/utils/kitlog.h"
 
 #define KIT_VIDEO_SYNC_THRESHOLD 0.02
 
@@ -93,67 +91,6 @@ static void free_out_video_packet_cb(void *packet) {
     free(p);
 }
 
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(57, 48, 101)
-static int dec_decode_video_cb(Kit_Decoder *dec, AVPacket *in_packet) {
-    assert(dec != NULL);
-    
-    if(in_packet == NULL) {
-        return 0;
-    }
-    
-    Kit_VideoDecoder *video_dec = dec->userdata;
-    AVFrame *out_frame = NULL;
-    Kit_VideoPacket *out_packet = NULL;
-    int frame_finished;
-    int len;
-    double pts;
-
-    while(in_packet->size > 0) {
-        len = avcodec_decode_video2(dec->codec_ctx, video_dec->scratch_frame, &frame_finished, in_packet);
-        if(len < 0) {
-            return 0;
-        }
-
-        if(frame_finished) {
-            // Target frame
-            out_frame = av_frame_alloc();
-            av_image_alloc(
-                    out_frame->data,
-                    out_frame->linesize,
-                    dec->codec_ctx->width,
-                    dec->codec_ctx->height,
-                    _FindAVPixelFormat(dec->output.format),
-                    1);
-
-            // Scale from source format to target format, don't touch the size
-            sws_scale(
-                video_dec->sws,
-                (const unsigned char * const *)video_dec->scratch_frame->data,
-                video_dec->scratch_frame->linesize,
-                0,
-                dec->codec_ctx->height,
-                out_frame->data,
-                out_frame->linesize);
-
-            // Get presentation timestamp
-#ifndef FF_API_FRAME_GET_SET
-            pts = av_frame_get_best_effort_timestamp(video_dec->scratch_frame);
-#else
-            pts = video_dec->scratch_frame->best_effort_timestamp;
-#endif
-            pts *= av_q2d(dec->format_ctx->streams[dec->stream_index]->time_base);
-
-            // Lock, write to audio buffer, unlock
-            out_packet = _CreateVideoPacket(out_frame, pts);
-            Kit_WriteDecoderOutput(dec, out_packet);
-        }
-        in_packet->size -= len;
-        in_packet->data += len;
-    }
-
-    return 0;
-}
-#else
 static void dec_read_video(const Kit_Decoder *dec) {
     const Kit_VideoDecoder *video_dec = dec->userdata;
     AVFrame *out_frame = NULL;
@@ -199,7 +136,7 @@ static int dec_decode_video_cb(Kit_Decoder *dec, AVPacket *in_packet) {
     assert(in_packet != NULL);
 
     // Try to clear the buffer first. We might have too much content in the ffmpeg buffer,
-    /// so we want to clear it of outgoing data if we can.
+    // so we want to clear it of outgoing data if we can.
     dec_read_video(dec);
 
     // Write packet to the decoder for handling.
@@ -207,11 +144,10 @@ static int dec_decode_video_cb(Kit_Decoder *dec, AVPacket *in_packet) {
         return 1;
     }
 
-    // Some input data was put in succesfully, so try again to get frames.
+    // Some input data was put in successfully, so try again to get frames.
     dec_read_video(dec);
     return 0;
 }
-#endif
 
 static void dec_close_video_cb(Kit_Decoder *dec) {
     if(dec == NULL) return;
